@@ -14,7 +14,10 @@
 
 #include <libqalculate/includes.h>
 #include <libqalculate/util.h>
-#include <sys/time.h>
+
+#ifndef _MSC_VER
+#	include <sys/time.h>
+#endif
 
 /** @file */
 
@@ -717,6 +720,22 @@ class Calculator {
 	bool hasToExpression(const std::string &str, bool allow_empty_from = false) const;
 	bool hasToExpression(const std::string &str, bool allow_empty_from, const EvaluationOptions &eo) const;
 
+	/** Parses a "to"-expression (separated from expression using separateToExpression).
+	 *
+	 * @param to_str The "to"-expression
+	 * @param[out] evalops Updated with directives from the expression
+	 * @param[out] printops Updated with directives from the expression
+	 * @param[out] custom_base Set to non-zero if conversion to custom number base (with Calculator::setCustomOutputBase()) is requested
+	 * @param[out] binary_prefixes Set to 2 if temporary activation of binary prefixes (using Calculator::useBinaryPrefixes()) is requested, 0 for requested deactivation, and -1 otherwise
+	 * @param[out] complex_angle_form Set to true (and evalops.complex_number_form to COMPLEX_FORM_CIS) if complex angle form is requested
+	 * @param[out] do_factors Set to true (and evalops.structuring to STRUCTURING_FACTORIZE) if factorization is requested
+	 * @param[out] do_pfe Set to true if partial fraction expansion is requested
+	 * @param[out] do_calendars Set to true if calendar conversion is requested
+	 * @param[out] do_bases Set to true if expression includes "to bases"
+	 * @returns the remaining unit expression
+	 */
+	std::string parseToExpression(std::string to_str, EvaluationOptions &evalops, PrintOptions &printops, Number *custom_base = NULL, int *binary_prefixes = NULL, bool *complex_angle_form = NULL, bool *do_factors = NULL, bool *do_pfe = NULL, bool *do_calendars = NULL, bool *do_bases = NULL) const;
+
 	/// Split an expression string after and before " where ".
 	bool separateWhereExpression(std::string &str, std::string &where_str, const EvaluationOptions &eo) const;
 	bool hasWhereExpression(const std::string &str, const EvaluationOptions &eo) const;
@@ -1348,6 +1367,8 @@ void print_dual(const MathStructure &mresult, const std::string &original_expres
 void calculate_dual_exact(MathStructure &mstruct_exact, MathStructure *mstruct, const std::string &original_expression, const MathStructure *parsed_mstruct, EvaluationOptions &evalops, AutomaticApproximation auto_approx, int msecs = 0, int max_size = 10);
 bool transform_expression_for_equals_save(std::string&, const ParseOptions&);
 MathStructure get_units_for_parsed_expression(const MathStructure *parsed_struct, Unit *to_unit, const EvaluationOptions &eo, const MathStructure *mstruct = NULL);
+MathStructure get_units_for_parsed_expression(const MathStructure *parsed_struct, Unit *to_unit, const EvaluationOptions &eo, const MathStructure *mstruct, std::string parsed_text);
 bool expression_contains_save_function(const std::string&, const ParseOptions&, bool = false);
+void convert_unchanged_quantity_with_unit(const MathStructure &mp, MathStructure &mr, EvaluationOptions &eo);
 
 #endif
